package com.tzld.longarticle.recommend.server;

import com.alibaba.fastjson.JSONObject;
import com.tzld.longarticle.recommend.server.model.dto.kimi.KimiResult;
import com.tzld.longarticle.recommend.server.remote.KimiApiService;
import okhttp3.*;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;

import javax.annotation.Resource;
import java.util.concurrent.TimeUnit;

@SpringBootTest(classes = Application.class)
public class KimiTest {

    @Resource
    private KimiApiService kimiApiService;

    @Test
    public void kimiApi() {
        String prompt =  "请帮我完成以下任务：输入为文章的标题，根据标题判断其内容所属的类目，输出为文章标题及其对应的类目。\n" +
                "类目需从以下范围内选择：\n" +
                "奇闻趣事\n" +
                "历史人物\n" +
                "家长里短\n" +
                "温情故事\n" +
                "健康养生\n" +
                "生活知识\n" +
                "名人八卦\n" +
                "政治新闻\n" +
                "军事新闻\n" +
                "影视解读\n" +
                "社会现象\n" +
                "人情世故\n" +
                "财经科技\n" +
                "子女教育\n" +
                "职场经验\n" +
                "为了更好地完成任务，可参考下列对文章标题的分类：\n" +
                "{\n" +
                "\"大舅病了，我取了三万元送过去，病房门口听到舅妈的话我改了主意\": \"家长里短\",\n" +
                "\"能活到90岁的老人，基本上在70岁的时候，就不再做这些事了！\": \"健康养生\",\n" +
                "\"去医院看望病人时，切忌带这4样东西，再亲近也不行，这是做人的根本\": \"生活知识\",\n" +
                "\"上海一女子去饭店吃生煎包，戳了个洞想凉一凉，往里一看，瞬间惊呆了\": \"奇闻趣事\",\n" +
                "\"卫生间放一把食盐，一年能省下好几百，涨新知识\": \"生活知识\",\n" +
                "\"中国有一古寺，庙不大，却有武警24小时站岗，到底有何“过人”之处\": \"奇闻趣事\",\n" +
                "\"1974年，苏联外长故意拿邓小平身高“取笑”，邓小平一句话轻松反击\": \"历史人物\",\n" +
                "\"中国最美的女将军：上世纪曾家喻户晓，如今仍然健在\": \"历史人物\",\n" +
                "\"北大才女蒙曼48岁仍未婚，被问最想嫁给谁，一个名字让全场笑喷\": \"名人八卦\",\n" +
                "\"广东一老人去世，家人把老人的旧床垫扔了，环卫工人看到后，竟发现里面藏了15万元现金！家人傻眼了\": \"奇闻趣事\",\n" +
                "\"《孤舟》结局：要不是海沫2年不生娃，周知非至死不知，顾易中要3000元的报销费的真实目的！\": \"影视解读\"\n" +
                "}\n" +
                "最后输出结果请用JSON格式输出，key为title，value为类目，仅输出JSON，不要markdown格式，不要任何其他内容，\n" +
                "并且内容可以被 fastJSON 的JSONObject.parseObject转换为JSON对象\n" +
                "当标题的开头或结尾为以下字符时“”“，则在标题的开头或结尾增加\"\n" +
                "输出结果格式如下：\n" +
                "{\n" +
                "\"浙江老人用“假钱”吃霸王餐9年，离世后，老板却崩溃大哭：“每天都在等他！”\": \"奇闻趣事\",\n" +
                "\"“最美婴儿”迅速走红，像在娘胎里整过容，网友：看到第一眼就想抱回家\": \"奇闻趣事\"\n" +
                "}\n" +
                "以下是需要分析的文章标题列表，每一行是一个标题：\n" +
                "往冰箱里面放个口罩，一年能省好几百的电费，这也太神奇了吧！\n" +
                "福建一女子偶遇4楼防盗网衣服挂成“墙”，晚上再看更是哭笑不得\n" +
                "1946年，6000名解放军被30000敌军包围，一地主：我一人就可退敌\n" +
                "扔废品时，鸡蛋托盘一定要留下！放阳台太厉害了，邻居见了纷纷学\n" +
                "10岁男孩高铁买三份饭，被父母怒骂：你穷，不是他的错！\n" +
                "知道吗？超市里临过期牛奶都去哪里了？内部销售员终于说出实情\n" +
                "人到了五十岁，子女给你这些东西要拒绝，避免晚年难熬\n" +
                "至今健在的开国将帅只剩一位，今101岁高龄身体依旧硬朗，他是谁？\n" +
                "李敏和母亲贺子珍的合影，娘俩长得挺像，尤其是嘴角和眼睛\n" +
                "1946年，6000名解放军被30000敌军包围，一地主：我一人就可退敌\n" +
                "福建一女子偶遇4楼防盗网衣服挂成“墙”，晚上再看更是哭笑不得";
        KimiResult kimiResult = kimiApiService.requestOfficialApi(prompt, null, null);

        OkHttpClient client = new OkHttpClient().newBuilder()
                .connectTimeout(15, TimeUnit.MINUTES)
                .readTimeout(15, TimeUnit.MINUTES)
                .writeTimeout(15, TimeUnit.MINUTES)
                .build();
        MediaType mediaType = MediaType.parse("application/json");
        JSONObject param = new JSONObject();
        param.put("prompt", prompt);
        RequestBody body = RequestBody.create(mediaType, param.toJSONString());
        Request request = new Request.Builder()
                .url("http://crawler.aiddit.com/crawler/moonshot/kimi")
                .method("POST", body)
                .addHeader("Content-Type", "application/json")
                .build();
        Response response = null;
        try {
            response = client.newCall(request).execute();
        } catch (Exception e) {
        }
        String responseContent = null;
        try {
            responseContent = response.body().string();
        } catch (Exception e) {
        }
        System.out.println("kimi api responseContent = {}" + responseContent);
    }

    public static void main(String[] args) {
        String str = "{\n\"女子做流产手术时不幸身亡，丈夫赶到医院讨说法，医生大惊：她老公已拿走55万赔偿，不是你吗？\": \"社会现象\",\n\"我妈交了15年社保，昨天第一次领退休金看到钱居然哭了\": \"家长里短\",\n\"河南男子发现捞到一条鱼疑似卡着金镯子，勒得变形出血！这是自带赎金？网友：拉鱼十几年头一次见\": \"奇闻趣事\",\n\"嫁到四川3年的印度美女，回国后父母不敢认：这还是我女儿吗？\": \"奇闻趣事\",\n\"新郎结婚当天，突然向长嫂下跪，把长嫂当场整哭了！\": \"家长里短\",\n\"1961年，陈毅看望班禅被请吃苹果，失口说好久吃不上苹果\": \"历史人物\",\n\"康熙口误叫错一水果名字，后人也跟着叫错三百年，至今仍读错\": \"历史人物\",\n\"川军排长失踪，妻子苦等60年，改嫁时发现对方是丈夫\": \"历史人物\",\n\"1953年，乔冠华酒后对李克农出言不逊，李克农：眼里没几个人要吃大亏\": \"历史人物\",\n\"男员工误入女厕，吓得女员工尖叫连连，领导为息事宁人将其开除\": \"职场经验\"\n}";
        JSONObject jsonObject = JSONObject.parseObject(str);
        System.out.println(jsonObject.toJSONString());
    }
}
